@@ -109,11 +109,16 @@ class FactorGraph:
 
         Args:
             variable_names: A list containing the connected variable names.
+                Variable names are tuples of the type (variable_group_name, variable_name_within_variable_group)
             factor_configs: Array of shape (num_val_configs, num_variables)
-                An array containing explicit enumeration of all valid configurations
-            log_potentials: Optional array of shape (num_val_configs,) or (num_factors, num_val_configs).
-                If specified, it contains the log of the potential value for every possible configuration.
-                If none, it is assumed the log potential is uniform 0 and such an array is automatically
+                An array containing explicit enumeration of all valid configurations.
+                If the connected variables have n1, n2, ... states, 1 <= num_val_configs <= n1 * n2 * ...
+                factor_configs[config_idx, variable_idx] represents the state of variable_names[variable_idx]
+                in the configuration factor_configs[config_idx].
+            log_potentials: Optional array of shape (num_val_configs,).
+                If specified, log_potentials[config_idx] contains the log of the potential value for
+                the valid configuration factor_configs[config_idx].
+                If None, it is assumed the log potential is uniform 0 and such an array is automatically
                 initialized.
         """
         factor_group = groups.EnumerationFactorGroup(
